==> ejc-credentials-impl-3.0.0-20220523.080402-30-sources.jar: com/ejianc/certify/vo/CorpCertifFVO.java <==
package com.ejianc.certify.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 证件借用配件-配证详情
 * 
 * @author generator
 * 
 */
public class CorpCertifFVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer crowno; // 行号
    private Date ts; // 时间戳
    private Long pkCorpcertify; // 主表主键
    private Long pkCorpcertifyB; // 证件配件子表主键
    private Long pkCertifreg; // 证照登记
    private Long pkCertiftype; // 证书类别
    private Long pkCertpsn; // 证书人员
    private String certifcode; // 证书编号
    private String jydate; // 配证日期
    private String isjyyj; // 原件/扫描件
    private String vmemo; // 备注
    private String yjjcDate; // 原件借出日期
    private String yjghDate; // 原件归还日期
    private String isgh; // 是否已归还
    private String isyyz; // 是否已押证
    private String isbjsuccess; // 是否报建成功
    private Long pkReplaceCertifreg; // 替换证书登记
    private Long pkReplaceCertpsn; // 替换证书人员
    private Long pkReplaceCertiftype; // 替换证书类别
    private String replaceCertifcode; // 替换证书编号
    private String replaceTime; // 替换时间
    private String replaceReason; // 替换原因
    private String yzstatus; // 用证状态（1-正常使用中 2-终止使用）
    private String useTime; // 开始使用时间
    private String finishTime; // 终止使用时间
    private String vdef1; // 
    private String vdef10; // 
    private String vdef2; // 
    private String vdef3; // 
    private String vdef4; // 
    private String vdef5; // 
    private String vdef6; // 
    private String vdef7; // 
    private String vdef8; // 
    private String vdef9; // 
    

    public Integer getCrowno() {
        return crowno;
    }

    public void setCrowno(Integer crowno) {
        this.crowno = crowno;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    public Long getPkCorpcertify() {
        return pkCorpcertify;
    }

    public void setPkCorpcertify(Long pkCorpcertify) {
        this.pkCorpcertify = pkCorpcertify;
    }
    public Long getPkCorpcertifyB() {
        return pkCorpcertifyB;
    }

    public void setPkCorpcertifyB(Long pkCorpcertifyB) {
        this.pkCorpcertifyB = pkCorpcertifyB;
    }
    public Long getPkCertifreg() {
        return pkCertifreg;
    }

    public void setPkCertifreg(Long pkCertifreg) {
        this.pkCertifreg = pkCertifreg;
    }
    public Long getPkCertiftype() {
        return pkCertiftype;
    }

    public void setPkCertiftype(Long pkCertiftype) {
        this.pkCertiftype = pkCertiftype;
    }
    public Long getPkCertpsn() {
        return pkCertpsn;
    }

    public void setPkCertpsn(Long pkCertpsn) {
        this.pkCertpsn = pkCertpsn;
    }
    public String getCertifcode() {
        return certifcode;
    }

    public void setCertifcode(String certifcode) {
        this.certifcode = certifcode;
    }
    public String getJydate() {
        return jydate;
    }

    public void setJydate(String jydate) {
        this.jydate = jydate;
    }
    public String getIsjyyj() {
        return isjyyj;
    }

    public void setIsjyyj(String isjyyj) {
        this.isjyyj = isjyyj;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    public String getYjjcDate() {
        return yjjcDate;
    }

    public void setYjjcDate(String yjjcDate) {
        this.yjjcDate = yjjcDate;
    }
    public String getYjghDate() {
        return yjghDate;
    }

    public void setYjghDate(String yjghDate) {
        this.yjghDate = yjghDate;
    }
    public String getIsgh() {
        return isgh;
    }

    public void setIsgh(String isgh) {
        this.isgh = isgh;
    }
    public String getIsyyz() {
        return isyyz;
    }

    public void setIsyyz(String isyyz) {
        this.isyyz = isyyz;
    }
    public String getIsbjsuccess() {
        return isbjsuccess;
    }

    public void setIsbjsuccess(String isbjsuccess) {
        this.isbjsuccess = isbjsuccess;
    }
    public Long getPkReplaceCertifreg() {
        return pkReplaceCertifreg;
    }

    public void setPkReplaceCertifreg(Long pkReplaceCertifreg) {
        this.pkReplaceCertifreg = pkReplaceCertifreg;
    }
    public Long getPkReplaceCertpsn() {
        return pkReplaceCertpsn;
    }

    public void setPkReplaceCertpsn(Long pkReplaceCertpsn) {
        this.pkReplaceCertpsn = pkReplaceCertpsn;
    }
    public Long getPkReplaceCertiftype() {
        return pkReplaceCertiftype;
    }

    public void setPkReplaceCertiftype(Long pkReplaceCertiftype) {
        this.pkReplaceCertiftype = pkReplaceCertiftype;
    }
    public String getReplaceCertifcode() {
        return replaceCertifcode;
    }

    public void setReplaceCertifcode(String replaceCertifcode) {
        this.replaceCertifcode = replaceCertifcode;
    }
    public String getReplaceTime() {
        return replaceTime;
    }

    public void setReplaceTime(String replaceTime) {
        this.replaceTime = replaceTime;
    }
    public String getReplaceReason() {
        return replaceReason;
    }

    public void setReplaceReason(String replaceReason) {
        this.replaceReason = replaceReason;
    }
    public String getYzstatus() {
        return yzstatus;
    }

    public void setYzstatus(String yzstatus) {
        this.yzstatus = yzstatus;
    }
    public String getUseTime() {
        return useTime;
    }

    public void setUseTime(String useTime) {
        this.useTime = useTime;
    }
    public String getFinishTime() {
        return finishTime;
    }

    public void setFinishTime(String finishTime) {
        this.finishTime = finishTime;
    }
    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }
    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }
    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }
    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }
    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }
    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }
    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }
    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }
    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }
    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }
    
}

==> ejc-credentials-impl-3.0.0-20220608.025626-40-sources.jar: com/ejianc/certify/vo/CorpCertifFVO.java <==
package com.ejianc.certify.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 证件借用配件-配证详情
 * 
 * @author generator
 * 
 */
public class CorpCertifFVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer crowno; // 行号
    private Date ts; // 时间戳
    private Long pkCorpcertify; // 主表主键
    private Long pkCorpcertifyB; // 证件配件子表主键
    private Long pkCertifreg; // 证照登记
    private Long pkCertiftype; // 证书类别
    private Long pkCertpsn; // 证书人员
    private String certifcode; // 证书编号
    private String jydate; // 配证日期
    private String isjyyj; // 原件/扫描件
    private String vmemo; // 备注
    private String yjjcDate; // 原件借出日期
    private String yjghDate; // 原件归还日期
    private String isgh; // 是否已归还
    private String isyyz; // 是否已押证
    private String isbjsuccess; // 是否报建成功
    private Long pkReplaceCertifreg; // 替换证书登记
    private Long pkReplaceCertpsn; // 替换证书人员
    private Long pkReplaceCertiftype; // 替换证书类别
    private String replaceCertifcode; // 替换证书编号
    private String replaceTime; // 替换时间
    private String replaceReason; // 替换原因
    private String yzstatus; // 用证状态（1-正常使用中 2-终止使用）
    private String useTime; // 开始使用时间
    private String finishTime; // 终止使用时间
    private String vdef1; // 
    private String vdef10; // 
    private String vdef2; // 
    private String vdef3; // 
    private String vdef4; // 
    private String vdef5; // 
    private String vdef6; // 
    private String vdef7; // 
    private String vdef8; // 
    private String vdef9; //
    private String isfk;

    public String getIsfk() {
        return isfk;
    }

    public void setIsfk(String isfk) {
        this.isfk = isfk;
    }

    public Integer getCrowno() {
        return crowno;
    }

    public void setCrowno(Integer crowno) {
        this.crowno = crowno;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    public Long getPkCorpcertify() {
        return pkCorpcertify;
    }

    public void setPkCorpcertify(Long pkCorpcertify) {
        this.pkCorpcertify = pkCorpcertify;
    }
    public Long getPkCorpcertifyB() {
        return pkCorpcertifyB;
    }

    public void setPkCorpcertifyB(Long pkCorpcertifyB) {
        this.pkCorpcertifyB = pkCorpcertifyB;
    }

    @ReferSerialTransfer(referCode = "certifyregH")
    public Long getPkCertifreg() {
        return pkCertifreg;
    }
    @ReferDeserialTransfer
    public void setPkCertifreg(Long pkCertifreg) {
        this.pkCertifreg = pkCertifreg;
    }

    @ReferSerialTransfer(referCode = "certifType")
    public Long getPkCertiftype() {
        return pkCertiftype;
    }
    @ReferDeserialTransfer
    public void setPkCertiftype(Long pkCertiftype) {
        this.pkCertiftype = pkCertiftype;
    }

    @ReferSerialTransfer(referCode = "idm-user")
    public Long getPkCertpsn() {
        return pkCertpsn;
    }
    @ReferDeserialTransfer
    public void setPkCertpsn(Long pkCertpsn) {
        this.pkCertpsn = pkCertpsn;
    }

    public String getCertifcode() {
        return certifcode;
    }

    public void setCertifcode(String certifcode) {
        this.certifcode = certifcode;
    }
    public String getJydate() {
        return jydate;
    }

    public void setJydate(String jydate) {
        this.jydate = jydate;
    }
    public String getIsjyyj() {
        return isjyyj;
    }

    public void setIsjyyj(String isjyyj) {
        this.isjyyj = isjyyj;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    public String getYjjcDate() {
        return yjjcDate;
    }

    public void setYjjcDate(String yjjcDate) {
        this.yjjcDate = yjjcDate;
    }
    public String getYjghDate() {
        return yjghDate;
    }

    public void setYjghDate(String yjghDate) {
        this.yjghDate = yjghDate;
    }
    public String getIsgh() {
        return isgh;
    }

    public void setIsgh(String isgh) {
        this.isgh = isgh;
    }
    public String getIsyyz() {
        return isyyz;
    }

    public void setIsyyz(String isyyz) {
        this.isyyz = isyyz;
    }
    public String getIsbjsuccess() {
        return isbjsuccess;
    }

    public void setIsbjsuccess(String isbjsuccess) {
        this.isbjsuccess = isbjsuccess;
    }

    @ReferSerialTransfer(referCode = "certifyregH")
    public Long getPkReplaceCertifreg() {
        return pkReplaceCertifreg;
    }
    @ReferDeserialTransfer
    public void setPkReplaceCertifreg(Long pkReplaceCertifreg) {
        this.pkReplaceCertifreg = pkReplaceCertifreg;
    }

    @ReferSerialTransfer(referCode = "idm-user")
    public Long getPkReplaceCertpsn() {
        return pkReplaceCertpsn;
    }
    @ReferDeserialTransfer
    public void setPkReplaceCertpsn(Long pkReplaceCertpsn) {
        this.pkReplaceCertpsn = pkReplaceCertpsn;
    }

    @ReferSerialTransfer(referCode = "certifType")
    public Long getPkReplaceCertiftype() {
        return pkReplaceCertiftype;
    }
    @ReferDeserialTransfer
    public void setPkReplaceCertiftype(Long pkReplaceCertiftype) {
        this.pkReplaceCertiftype = pkReplaceCertiftype;
    }

    public String getReplaceCertifcode() {
        return replaceCertifcode;
    }

    public void setReplaceCertifcode(String replaceCertifcode) {
        this.replaceCertifcode = replaceCertifcode;
    }
    public String getReplaceTime() {
        return replaceTime;
    }

    public void setReplaceTime(String replaceTime) {
        this.replaceTime = replaceTime;
    }
    public String getReplaceReason() {
        return replaceReason;
    }

    public void setReplaceReason(String replaceReason) {
        this.replaceReason = replaceReason;
    }
    public String getYzstatus() {
        return yzstatus;
    }

    public void setYzstatus(String yzstatus) {
        this.yzstatus = yzstatus;
    }
    public String getUseTime() {
        return useTime;
    }

    public void setUseTime(String useTime) {
        this.useTime = useTime;
    }
    public String getFinishTime() {
        return finishTime;
    }

    public void setFinishTime(String finishTime) {
        this.finishTime = finishTime;
    }
    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }
    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }
    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }
    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }
    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }
    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }
    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }
    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }
    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }
    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }
    
}
